==> kubernetes-model-flowcontrol-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/FlowSchemaSpecFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface FlowSchemaSpecFluent<A extends FlowSchemaSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildDistinguisherMethod instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowDistinguisherMethod getDistinguisherMethod();
  public FlowDistinguisherMethod buildDistinguisherMethod();
  public A withDistinguisherMethod(FlowDistinguisherMethod distinguisherMethod);
  public Boolean hasDistinguisherMethod();
  public A withNewDistinguisherMethod(String type);
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> withNewDistinguisherMethod();
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> withNewDistinguisherMethodLike(FlowDistinguisherMethod item);
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> editDistinguisherMethod();
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> editOrNewDistinguisherMethod();
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> editOrNewDistinguisherMethodLike(FlowDistinguisherMethod item);
  public Integer getMatchingPrecedence();
  public A withMatchingPrecedence(Integer matchingPrecedence);
  public Boolean hasMatchingPrecedence();
  
  /**
   * This method has been deprecated, please use method buildPriorityLevelConfiguration instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationReference getPriorityLevelConfiguration();
  public PriorityLevelConfigurationReference buildPriorityLevelConfiguration();
  public A withPriorityLevelConfiguration(PriorityLevelConfigurationReference priorityLevelConfiguration);
  public Boolean hasPriorityLevelConfiguration();
  public A withNewPriorityLevelConfiguration(String name);
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> withNewPriorityLevelConfiguration();
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> withNewPriorityLevelConfigurationLike(PriorityLevelConfigurationReference item);
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> editPriorityLevelConfiguration();
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> editOrNewPriorityLevelConfiguration();
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> editOrNewPriorityLevelConfigurationLike(PriorityLevelConfigurationReference item);
  public A addToRules(Integer index,PolicyRulesWithSubjects item);
  public A setToRules(Integer index,PolicyRulesWithSubjects item);
  public A addToRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PolicyRulesWithSubjects... items);
  public A addAllToRules(Collection<PolicyRulesWithSubjects> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PolicyRulesWithSubjects... items);
  public A removeAllFromRules(Collection<PolicyRulesWithSubjects> items);
  public A removeMatchingFromRules(Predicate<PolicyRulesWithSubjectsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PolicyRulesWithSubjects> getRules();
  public List<PolicyRulesWithSubjects> buildRules();
  public PolicyRulesWithSubjects buildRule(Integer index);
  public PolicyRulesWithSubjects buildFirstRule();
  public PolicyRulesWithSubjects buildLastRule();
  public PolicyRulesWithSubjects buildMatchingRule(Predicate<PolicyRulesWithSubjectsBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<PolicyRulesWithSubjectsBuilder> predicate);
  public A withRules(List<PolicyRulesWithSubjects> rules);
  public A withRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PolicyRulesWithSubjects... rules);
  public Boolean hasRules();
  public FlowSchemaSpecFluent.RulesNested<A> addNewRule();
  public FlowSchemaSpecFluent.RulesNested<A> addNewRuleLike(PolicyRulesWithSubjects item);
  public FlowSchemaSpecFluent.RulesNested<A> setNewRuleLike(Integer index,PolicyRulesWithSubjects item);
  public FlowSchemaSpecFluent.RulesNested<A> editRule(Integer index);
  public FlowSchemaSpecFluent.RulesNested<A> editFirstRule();
  public FlowSchemaSpecFluent.RulesNested<A> editLastRule();
  public FlowSchemaSpecFluent.RulesNested<A> editMatchingRule(Predicate<PolicyRulesWithSubjectsBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface DistinguisherMethodNested<N> extends Nested<N>,FlowDistinguisherMethodFluent<FlowSchemaSpecFluent.DistinguisherMethodNested<N>>{
    public N and();
    public N endDistinguisherMethod();
    
  }
  public interface PriorityLevelConfigurationNested<N> extends Nested<N>,PriorityLevelConfigurationReferenceFluent<FlowSchemaSpecFluent.PriorityLevelConfigurationNested<N>>{
    public N and();
    public N endPriorityLevelConfiguration();
    
  }
  public interface RulesNested<N> extends Nested<N>,PolicyRulesWithSubjectsFluent<FlowSchemaSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/FlowSchemaSpecFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface FlowSchemaSpecFluent<A extends FlowSchemaSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildDistinguisherMethod instead.
   * @return The buildable object.
   */
  @Deprecated
  public FlowDistinguisherMethod getDistinguisherMethod();
  public FlowDistinguisherMethod buildDistinguisherMethod();
  public A withDistinguisherMethod(FlowDistinguisherMethod distinguisherMethod);
  public Boolean hasDistinguisherMethod();
  public A withNewDistinguisherMethod(String type);
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> withNewDistinguisherMethod();
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> withNewDistinguisherMethodLike(FlowDistinguisherMethod item);
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> editDistinguisherMethod();
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> editOrNewDistinguisherMethod();
  public FlowSchemaSpecFluent.DistinguisherMethodNested<A> editOrNewDistinguisherMethodLike(FlowDistinguisherMethod item);
  public Integer getMatchingPrecedence();
  public A withMatchingPrecedence(Integer matchingPrecedence);
  public Boolean hasMatchingPrecedence();
  
  /**
   * This method has been deprecated, please use method buildPriorityLevelConfiguration instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationReference getPriorityLevelConfiguration();
  public PriorityLevelConfigurationReference buildPriorityLevelConfiguration();
  public A withPriorityLevelConfiguration(PriorityLevelConfigurationReference priorityLevelConfiguration);
  public Boolean hasPriorityLevelConfiguration();
  public A withNewPriorityLevelConfiguration(String name);
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> withNewPriorityLevelConfiguration();
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> withNewPriorityLevelConfigurationLike(PriorityLevelConfigurationReference item);
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> editPriorityLevelConfiguration();
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> editOrNewPriorityLevelConfiguration();
  public FlowSchemaSpecFluent.PriorityLevelConfigurationNested<A> editOrNewPriorityLevelConfigurationLike(PriorityLevelConfigurationReference item);
  public A addToRules(int index,PolicyRulesWithSubjects item);
  public A setToRules(int index,PolicyRulesWithSubjects item);
  public A addToRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PolicyRulesWithSubjects... items);
  public A addAllToRules(Collection<PolicyRulesWithSubjects> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PolicyRulesWithSubjects... items);
  public A removeAllFromRules(Collection<PolicyRulesWithSubjects> items);
  public A removeMatchingFromRules(Predicate<PolicyRulesWithSubjectsBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PolicyRulesWithSubjects> getRules();
  public List<PolicyRulesWithSubjects> buildRules();
  public PolicyRulesWithSubjects buildRule(int index);
  public PolicyRulesWithSubjects buildFirstRule();
  public PolicyRulesWithSubjects buildLastRule();
  public PolicyRulesWithSubjects buildMatchingRule(Predicate<PolicyRulesWithSubjectsBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<PolicyRulesWithSubjectsBuilder> predicate);
  public A withRules(List<PolicyRulesWithSubjects> rules);
  public A withRules(io.fabric8.kubernetes.api.model.flowcontrol.v1beta2.PolicyRulesWithSubjects... rules);
  public Boolean hasRules();
  public FlowSchemaSpecFluent.RulesNested<A> addNewRule();
  public FlowSchemaSpecFluent.RulesNested<A> addNewRuleLike(PolicyRulesWithSubjects item);
  public FlowSchemaSpecFluent.RulesNested<A> setNewRuleLike(int index,PolicyRulesWithSubjects item);
  public FlowSchemaSpecFluent.RulesNested<A> editRule(int index);
  public FlowSchemaSpecFluent.RulesNested<A> editFirstRule();
  public FlowSchemaSpecFluent.RulesNested<A> editLastRule();
  public FlowSchemaSpecFluent.RulesNested<A> editMatchingRule(Predicate<PolicyRulesWithSubjectsBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface DistinguisherMethodNested<N> extends Nested<N>,FlowDistinguisherMethodFluent<FlowSchemaSpecFluent.DistinguisherMethodNested<N>>{
    public N and();
    public N endDistinguisherMethod();
    
  }
  public interface PriorityLevelConfigurationNested<N> extends Nested<N>,PriorityLevelConfigurationReferenceFluent<FlowSchemaSpecFluent.PriorityLevelConfigurationNested<N>>{
    public N and();
    public N endPriorityLevelConfiguration();
    
  }
  public interface RulesNested<N> extends Nested<N>,PolicyRulesWithSubjectsFluent<FlowSchemaSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}
